@@ -1,12 +1,13 @@
 /*-------------------------------------------------------------------------
  *
- * rusagestub.h--
+ * rusagestub.h
  *	  Stubs for getrusage(3).
  *
  *
- * Copyright (c) 1994, Regents of the University of California
+ * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: rusagestub.h,v 1.3 1998/09/01 04:34:02 momjian Exp $
+ * $Id: rusagestub.h,v 1.12 2003/08/04 02:40:10 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -14,7 +15,9 @@
 #define RUSAGESTUB_H
 
 #include <sys/time.h>			/* for struct timeval */
+#ifndef WIN32
 #include <sys/times.h>			/* for struct tms */
+#endif
 #include <limits.h>				/* for CLK_TCK */
 
 #define RUSAGE_SELF		0
@@ -28,4 +31,4 @@ struct rusage
 
 extern int	getrusage(int who, struct rusage * rusage);
 
-#endif	 /* RUSAGESTUB_H */
+#endif   /* RUSAGESTUB_H */
